astro_axis_t

Struct astro_axis_t 

#[repr(C)]
pub struct astro_axis_t { pub status: astro_status_t, pub ra: f64, pub dec: f64, pub spin: f64, pub north: astro_vector_t, }
@brief Information about a body’s rotation axis at a given time.

This structure is returned by #Astronomy_RotationAxis to report the orientation of a body’s rotation axis at a given moment in time. The axis is specified by the direction in space that the body’s north pole points, using angular equatorial coordinates in the J2000 system (EQJ).

Thus ra is the right ascension, and dec is the declination, of the body’s north pole vector at the given moment in time. The north pole of a body is defined as the pole that lies on the north side of the Solar System’s invariable plane, regardless of the body’s direction of rotation.

The spin field indicates the angular position of a prime meridian arbitrarily recommended for the body by the International Astronomical Union (IAU).

The fields ra, dec, and spin correspond to the variables α0, δ0, and W, respectively, from Report of the IAU Working Group on Cartographic Coordinates and Rotational Elements: 2015.

The field north is a unit vector pointing in the direction of the body’s north pole. It is expressed in the equatorial J2000 system (EQJ).

Fields

status: astro_status_t

< ASTRO_SUCCESS if this struct is valid; otherwise an error code.

ra: f64

< The J2000 right ascension of the body’s north pole direction, in sidereal hours.

dec: f64

< The J2000 declination of the body’s north pole direction, in degrees.

spin: f64

< Rotation angle of the body’s prime meridian, in degrees.

north: astro_vector_t

< A J2000 dimensionless unit vector pointing in the direction of the body’s north pole.