astro_observer_t

Struct astro_observer_t 

#[repr(C)]
pub struct astro_observer_t { pub latitude: f64, pub longitude: f64, pub height: f64, }
@brief The location of an observer on (or near) the surface of the Earth.

This structure is passed to functions that calculate phenomena as observed from a particular place on the Earth.

You can create this structure directly, or you can call the convenience function #Astronomy_MakeObserver to create one for you.

Fields

latitude: f64

< Geographic latitude in degrees north (positive) or south (negative) of the equator.

longitude: f64

< Geographic longitude in degrees east (positive) or west (negative) of the prime meridian at Greenwich, England.

height: f64

< The height above (positive) or below (negative) sea level, expressed in meters.