#[repr(C)]pub struct astro_state_vector_t {
pub status: astro_status_t,
pub x: f64,
pub y: f64,
pub z: f64,
pub vx: f64,
pub vy: f64,
pub vz: f64,
pub t: astro_time_t,
}Expand description
@brief A state vector that contains a position (AU) and velocity (AU/day).
Fields
status: astro_status_t< ASTRO_SUCCESS if this struct is valid; otherwise an error code.
x: f64< The Cartesian position x-coordinate of the vector in AU.
y: f64< The Cartesian position y-coordinate of the vector in AU.
z: f64< The Cartesian position z-coordinate of the vector in AU.
vx: f64< The Cartesian velocity x-coordinate of the vector in AU/day.
vy: f64< The Cartesian velocity y-coordinate of the vector in AU/day.
vz: f64< The Cartesian velocity z-coordinate of the vector in AU/day.
t: astro_time_t< The date and time at which this state vector is valid.