#[repr(C)]pub struct astro_vector_t {
pub status: astro_status_t,
pub x: f64,
pub y: f64,
pub z: f64,
pub t: astro_time_t,
}Expand description
@brief A 3D Cartesian vector whose components are expressed in Astronomical Units (AU).
Fields
status: astro_status_t< ASTRO_SUCCESS if this struct is valid; otherwise an error code.
x: f64< The Cartesian x-coordinate of the vector in AU.
y: f64< The Cartesian y-coordinate of the vector in AU.
z: f64< The Cartesian z-coordinate of the vector in AU.
t: astro_time_t< The date and time at which this vector is valid.