#[repr(C)]pub struct astro_libration_t {
pub elat: f64,
pub elon: f64,
pub mlat: f64,
pub mlon: f64,
pub dist_km: f64,
pub diam_deg: f64,
}Expand description
@brief Lunar libration angles, returned by #Astronomy_Libration.
Fields
elat: f64< Sub-Earth libration ecliptic latitude angle, in degrees.
elon: f64< Sub-Earth libration ecliptic longitude angle, in degrees.
mlat: f64< Moon’s geocentric ecliptic latitude, in degrees.
mlon: f64< Moon’s geocentric ecliptic longitude, in degrees.
dist_km: f64< Distance between the centers of the Earth and Moon in kilometers.
diam_deg: f64< The apparent angular diameter of the Moon, in degrees, as seen from the center of the Earth.